using System;
using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    /// <summary>
    /// The most basic EQUI element, contains only an item identifier.
    /// </summary>
    public partial class Class : EQIA_Object
    {
        private EQInterface myInterface;
        private string myName;

        /// <summary>
        /// The interface this element belongs to.
        /// </summary>
        [XmlIgnore(), Browsable(false)]
        public EQInterface Interface { get { return myInterface; } set { myInterface = value; } }

        /// <summary>
        /// Name that can be used to refer to this element from anywhere in the ui.
        /// </summary>
        [XmlAttribute("item")]
        [Browsable(true), Description("Name that can be used to refer to this element from anywhere in the ui.")]
        public string Name { get { return myName; } set { myName = value; } }

        public Class()
            : this(null)
        {
        }

        public Class(EQInterface eqInterface)
            : base()
        {
            myName = string.Empty;
            myInterface = eqInterface;
        }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            Class temp_Class = obj as Class;
            if (temp_Class != null)
                Name = temp_Class.Name;
        }

        public override string ToString()
        {
            return myName;
        }
    }
}
